Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CloudFlareBanIP ¶ added in v1.2.0
CloudFlareBanIP will query the CloudFlare API and add the IP to ban to all zones
func PruneAnalytics ¶ added in v1.2.0
func PruneAnalytics()
PruneAnalytics will remove old entries from the analytics table
Types ¶
type PagedResponse ¶
type PagedResponse struct {
Total uint `json:"total"`
Limit uint `json:"limit"`
PerPage uint `json:"per_page"`
Pages uint `json:"pages"`
CurrentPage uint `json:"current_page"`
Items interface{} `json:"items"`
}
PagedResponse contains the fields for pagination in the JSON response and all model items
Click to show internal directories.
Click to hide internal directories.